@@ -190,7 +190,10 @@ class LearnRegressionError:
             if (model_predictions_validation < 0).any() or (self.validation['Current Model Error'] < 0).any():
                 pass
             else:
-                self.algorithm_performance_df.loc[key, 'Error Model Validation RMSLE'] = self.np.sqrt(mean_squared_log_error(self.validation['Current Model Error'],model_predictions_validation))
+                try:
+                    self.algorithm_performance_df.loc[key, 'Error Model Validation RMSLE'] = self.np.sqrt(mean_squared_log_error(self.validation['Current Model Error'],model_predictions_validation))
+                except ValueError:
+                    pass
             self.algorithm_performance_df.loc[key, 'Error Model Validation R2-Score'] = r2_score(self.validation['Current Model Error'], model_predictions_validation)
 
             # Populating Metric Scores for Test Error Model
@@ -201,9 +204,10 @@ class LearnRegressionError:
             if (model_predictions_validation < 0).any() or (self.test['Current Model Error'] < 0).any():
                 pass
             else:
-                self.algorithm_performance_df.loc[key, 'Error Model Test RMSLE'] = self.np.sqrt(
-                    mean_squared_log_error(self.test['Current Model Error'],
-                                                                model_predictions_test))
+                try:
+                    self.algorithm_performance_df.loc[key, 'Error Model Test RMSLE'] = self.np.sqrt(mean_squared_log_error(self.test['Current Model Error'],model_predictions_test))
+                except ValueError:
+                    pass
             self.algorithm_performance_df.loc[key, 'Error Model Test R2-Score'] = r2_score(
                 self.test['Current Model Error'], model_predictions_test)
 
@@ -218,9 +222,10 @@ class LearnRegressionError:
             if (final_output_validation < 0).any() or (self.validation[self.output_label] < 0).any():
                 pass
             else:
-                self.algorithm_performance_df.loc[key, 'Final Output Validation RMSLE'] = self.np.sqrt(
-                    mean_squared_log_error(self.validation[self.output_label],
-                                                                final_output_validation))
+                try:
+                    self.algorithm_performance_df.loc[key, 'Final Output Validation RMSLE'] = self.np.sqrt(mean_squared_log_error(self.validation[self.output_label],final_output_validation))
+                except ValueError:
+                    pass
             self.algorithm_performance_df.loc[key, 'Final Output Validation R2-Score'] = r2_score(
                 self.validation[self.output_label], final_output_validation)
 
@@ -234,8 +239,10 @@ class LearnRegressionError:
             if (final_output_test < 0).any() or (self.test[self.output_label] < 0).any():
                 pass
             else:
-                self.algorithm_performance_df.loc[key, 'Final Output Test RMSLE'] = self.np.sqrt(
-                    mean_squared_log_error(self.test[self.output_label], final_output_test))
+                try:
+                    self.algorithm_performance_df.loc[key, 'Final Output Test RMSLE'] = self.np.sqrt(mean_squared_log_error(self.test[self.output_label], final_output_test))
+                except ValueError:
+                    pass
             self.algorithm_performance_df.loc[key, 'Final Output Test R2-Score'] = r2_score(
                 self.test[self.output_label], final_output_test)
 
